glue\_genes.glue\_genomics\_data.spaceranger\_factory.read\_spaceranger\_directory
==================================================================================

.. currentmodule:: glue_genes.glue_genomics_data.spaceranger_factory

.. autofunction:: read_spaceranger_directory